@@ -18,8 +18,8 @@ macro_rules! partitions_from_table_source {
             io::BlobStoreType::Http => {
                 io::http::partitions_from_uri(&$table_source, uri, $call_with_r).await
             }
-            io::BlobStoreType::S3 => {
-                io::s3::partitions_from_uri(&$table_source, uri, $call_with_r).await
+            io::BlobStoreType::S3 | io::BlobStoreType::GCS | io::BlobStoreType::Azure => {
+                io::object_store::partitions_from_uri(&$table_source, uri, $call_with_r).await
             }
             io::BlobStoreType::Memory => {
                 io::memory::partitions_from_memory(&$table_source, $call_with_r).await
@@ -39,6 +39,7 @@ pub use crate::columnq::*;
 /// export datafusion and arrow so downstream won't need to declare dependencies on these libraries
 pub use datafusion;
 pub use datafusion::arrow;
+pub use sqlparser;
 
 #[cfg(test)]
 pub mod test_util;
