@@ -91,6 +91,8 @@ pub struct TableOptionCsv {
     delimiter: u8,
     #[serde(default = "TableOptionCsv::default_projection")]
     projection: Option<Vec<usize>>,
+    #[serde(default = "TableOptionCsv::default_use_memory_table")]
+    use_memory_table: bool,
 }
 
 impl TableOptionCsv {
@@ -135,6 +137,10 @@ impl TableOptionCsv {
             )),
         }
     }
+    #[inline]
+    pub fn default_use_memory_table() -> bool {
+        true
+    }
 }
 
 impl Default for TableOptionCsv {
@@ -143,6 +149,7 @@ impl Default for TableOptionCsv {
             has_header: Self::default_has_header(),
             delimiter: Self::default_delimiter(),
             projection: Self::default_projection(),
+            use_memory_table: Self::default_use_memory_table(),
         }
     }
 }
@@ -433,6 +440,7 @@ impl TableSource {
                     Some(ext) => match ext {
                         "csv" | "json" | "ndjson" | "jsonl" | "parquet" | "arrow" | "arrows"
                         | "xlsx" => ext,
+                        "sqlite" | "sqlite3" | "db" => "sqlite",
                         _ => {
                             return Err(ColumnQError::InvalidUri(format!(
                                 "unsupported extension in uri: {}",
@@ -465,15 +473,15 @@ impl TableSource {
     }
 }
 
-pub async fn load(t: &TableSource) -> Result<Arc<dyn TableProvider>, ColumnQError> {
+pub async fn load(t: &TableSource, dfctx: &datafusion::execution::context::SessionContext) -> Result<Arc<dyn TableProvider>, ColumnQError> {
     if let Some(opt) = &t.option {
         Ok(match opt {
             TableLoadOption::json { .. } => Arc::new(json::to_mem_table(t).await?),
             TableLoadOption::ndjson { .. } | TableLoadOption::jsonl { .. } => {
                 Arc::new(ndjson::to_mem_table(t).await?)
             }
-            TableLoadOption::csv { .. } => Arc::new(csv::to_mem_table(t).await?),
-            TableLoadOption::parquet { .. } => parquet::to_datafusion_table(t).await?,
+            TableLoadOption::csv { .. } => csv::to_datafusion_table(t).await?,
+            TableLoadOption::parquet { .. } => parquet::to_datafusion_table(t, dfctx).await?,
             TableLoadOption::google_spreadsheet(_) => {
                 Arc::new(google_spreadsheets::to_mem_table(t).await?)
             }
@@ -493,10 +501,10 @@ pub async fn load(t: &TableSource) -> Result<Arc<dyn TableProvider>, ColumnQErro
         })
     } else {
         let t: Arc<dyn TableProvider> = match t.extension()? {
-            "csv" => Arc::new(csv::to_mem_table(t).await?),
+            "csv" => csv::to_datafusion_table(t).await?,
             "json" => Arc::new(json::to_mem_table(t).await?),
             "ndjson" | "jsonl" => Arc::new(ndjson::to_mem_table(t).await?),
-            "parquet" => parquet::to_datafusion_table(t).await?,
+            "parquet" => parquet::to_datafusion_table(t, dfctx).await?,
             "arrow" => Arc::new(arrow_ipc_file::to_mem_table(t).await?),
             "arrows" => Arc::new(arrow_ipc_stream::to_mem_table(t).await?),
             "mysql" => Arc::new(database::DatabaseLoader::MySQL.to_mem_table(t)?),
@@ -695,9 +703,9 @@ batch_size: 512
     #[cfg(feature = "database-sqlite")]
     #[tokio::test]
     async fn test_load_sqlite_table() -> anyhow::Result<()> {
-        let t = TableSource::new("uk_cities", "sqlite://../test_data/sqlite.db");
-        let table = load(&t).await?;
+        let t = TableSource::new("uk_cities", "sqlite://../test_data/sqlite/sample.db");
         let ctx = datafusion::prelude::SessionContext::new();
+        let table = load(&t, &ctx).await?;
         let stats = table
             .scan(&ctx.state(), &None, &[], None)
             .await?
@@ -706,4 +714,26 @@ batch_size: 512
 
         Ok(())
     }
+
+    #[cfg(feature = "database-sqlite")]
+    #[tokio::test]
+    async fn test_load_sqlite_table_with_config() -> anyhow::Result<()> {
+        for ext in vec!["db", "sqlite", "sqlite3"] {
+            let t: TableSource = serde_yaml::from_str(&format!(
+                r#"
+name: "uk_cities"
+uri: "sqlite://../test_data/sqlite/sample.{}"
+"#,
+                ext
+            ))?;
+            let ctx = datafusion::prelude::SessionContext::new();
+            let table = load(&t, &ctx).await?;
+            let stats = table
+                .scan(&ctx.state(), &None, &[], None)
+                .await?
+                .statistics();
+            assert_eq!(stats.num_rows, Some(37));
+        }
+        Ok(())
+    }
 }
